@@ -36,6 +36,8 @@ class IntelliFireAPICloud(IntelliFireController, IntelliFireDataProvider):
             use_http (bool, optional): whether to use HTTP or HTTPS mode. Defaults to False.
             verify_ssl (bool, optional): Enable/Disable SSL Verification. Defaults to True.
         """
+        super(IntelliFireController, self).__init__()
+        super(IntelliFireDataProvider, self).__init__()
         self._cookie: Cookies = Cookies()
         self._is_logged_in = False
         self.default_fireplace: IntelliFireFireplace
@@ -51,7 +53,7 @@ class IntelliFireAPICloud(IntelliFireController, IntelliFireDataProvider):
     @property
     def data(self) -> IntelliFirePollData:
         """Return data to the user."""
-        if self._data.serial == "unset":
+        if self._data.ipv4_address == "127.0.0.1":
             _log.warning("Returning uninitialized poll data")
         return self._data
 
